==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/APMSCENARIOWOID_TYPE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour APMSCENARIOWOID_TYPE complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="APMSCENARIOWOID_TYPE">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APMSCENARIOID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APMSCENARIOWOID_TYPE", propOrder = {
    "apmscenarioid",
    "workorderid"
})
public class APMSCENARIOWOID_TYPE {

    @XmlElement(name = "APMSCENARIOID", required = true)
    protected STANDARDENTITYID_Type apmscenarioid;
    @XmlElement(name = "WORKORDERID", required = true)
    protected WOID_Type workorderid;

    /**
     * Obtient la valeur de la propriété apmscenarioid.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPMSCENARIOID() {
        return apmscenarioid;
    }

    /**
     * Définit la valeur de la propriété apmscenarioid.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPMSCENARIOID(STANDARDENTITYID_Type value) {
        this.apmscenarioid = value;
    }

    /**
     * Obtient la valeur de la propriété workorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Définit la valeur de la propriété workorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/APMSCENARIOWOID_TYPE.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for APMSCENARIOWOID_TYPE complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="APMSCENARIOWOID_TYPE">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APMSCENARIOID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APMSCENARIOWOID_TYPE", propOrder = {
    "apmscenarioid",
    "workorderid"
})
public class APMSCENARIOWOID_TYPE {

    @XmlElement(name = "APMSCENARIOID", required = true)
    protected STANDARDENTITYID_Type apmscenarioid;
    @XmlElement(name = "WORKORDERID", required = true)
    protected WOID_Type workorderid;

    /**
     * Gets the value of the apmscenarioid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getAPMSCENARIOID() {
        return apmscenarioid;
    }

    /**
     * Sets the value of the apmscenarioid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setAPMSCENARIOID(STANDARDENTITYID_Type value) {
        this.apmscenarioid = value;
    }

    /**
     * Gets the value of the workorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getWORKORDERID() {
        return workorderid;
    }

    /**
     * Sets the value of the workorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setWORKORDERID(WOID_Type value) {
        this.workorderid = value;
    }

}
